<?php
/**
 * Test cases for NOCC_Request.
 *
 * Copyright 2010-2011 Tim Gerundt <tim@gerundt.de>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Tests
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: NOCC_RequestTest.php 2373 2011-01-04 15:06:58Z gerundt $
 */

require_once 'PHPUnit/Framework.php';

require_once dirname(__FILE__).'/../../classes/nocc_request.php';

/**
 * Test class for NOCC_Request.
 * Generated by PHPUnit on 2010-04-03 at 19:05:16.
 */
class NOCC_RequestTest extends PHPUnit_Framework_TestCase {
    /**
     * @var array
     */
    protected $requestBackup;

    /**
     * Sets up the fixture, for example, opens a network connection.
     * This method is called before a test is executed.
     */
    protected function setUp() {
        $this->requestBackup = $_REQUEST;

        $_REQUEST['HelloWorldValue'] = 'Hello World!';
        $_REQUEST['TrueValue'] = 'true';
        $_REQUEST['FalseValue'] = 'false';
        $_REQUEST['1Value'] = '1';
        $_REQUEST['0Value'] = '0';
    }

    /**
     * Tears down the fixture, for example, closes a network connection.
     * This method is called after a test is executed.
     */
    protected function tearDown() {
        $_REQUEST = $this->requestBackup;
    }

    /**
     * Test case for getStringValue().
     */
    public function testGetStringValue() {
        $this->assertEquals('', NOCC_Request::getStringValue(null), 'NULL');
        $this->assertEquals('', NOCC_Request::getStringValue(''), '');
        $this->assertEquals('', NOCC_Request::getStringValue('notexists'), 'notexists');

        $this->assertEquals('Hello World!', NOCC_Request::getStringValue('HelloWorldValue'), 'HelloWorldValue');
    }

    /**
     * Test case for getBoolValue().
     */
    public function testGetBoolValue() {
        $this->assertFalse(NOCC_Request::getBoolValue(null), 'NULL');
        $this->assertFalse(NOCC_Request::getBoolValue(''), '');
        $this->assertFalse(NOCC_Request::getBoolValue('notexists'), 'notexists');
        $this->assertFalse(NOCC_Request::getBoolValue('notexists', null), 'notexists, NULL');
        $this->assertTrue(NOCC_Request::getBoolValue('notexists', 1), 'notexists, 1');
        $this->assertTrue(NOCC_Request::getBoolValue('notexists', true), 'notexists, true');

        $this->assertTrue(NOCC_Request::getBoolValue('TrueValue'), 'TrueValue');
        $this->assertFalse(NOCC_Request::getBoolValue('FalseValue'), 'FalseValue');
        $this->assertTrue(NOCC_Request::getBoolValue('1Value'), '1Value');
        $this->assertFalse(NOCC_Request::getBoolValue('0Value'), '0Value');
    }

    /**
     * Test case for convertToBool().
     */
    public function testConvertToBool() {
        $this->assertFalse(NOCC_Request::convertToBool(null), 'NULL');
        $this->assertFalse(NOCC_Request::convertToBool(''), '');
        $this->assertFalse(NOCC_Request::convertToBool('bug'), 'bug');
        $this->assertFalse(NOCC_Request::convertToBool('99'), '99');

        $this->assertTrue(NOCC_Request::convertToBool(true), 'true');
        $this->assertTrue(NOCC_Request::convertToBool(1), '1');
        $this->assertTrue(NOCC_Request::convertToBool('true'), '"true"');
        $this->assertTrue(NOCC_Request::convertToBool('1'), '"1"');
        $this->assertTrue(NOCC_Request::convertToBool('TruE'), '"TruE"');

        $this->assertFalse(NOCC_Request::convertToBool(false), 'false');
        $this->assertFalse(NOCC_Request::convertToBool(0), '0');
        $this->assertFalse(NOCC_Request::convertToBool('false'), '"false"');
        $this->assertFalse(NOCC_Request::convertToBool('0'), '"0"');
        $this->assertFalse(NOCC_Request::convertToBool('FaLsE'), '"FaLsE"');
    }
}
?>
